@@ -134,7 +134,7 @@ static gboolean bus_cb(GstBus *bus, GstMessage *msg, gpointer data)
 			event.user.code = SDL_CINEMAEVENT | SDL_CINEMA_ERR;
 			event.user.data1 = NULL;
 			event.user.data2 = NULL;
-			SDL_PushEvent(&event);
+			SDLPRE_PushEvent(&event);
 
 			g_error_free(err);
 			g_free(debug);
@@ -151,7 +151,7 @@ static gboolean bus_cb(GstBus *bus, GstMessage *msg, gpointer data)
 			event.user.code = SDL_CINEMAEVENT | SDL_CINEMA_EOS;
 			event.user.data1 = NULL;
 			event.user.data2 = NULL;
-			SDL_PushEvent(&event);
+			SDLPRE_PushEvent(&event);
 
 			bus_watch_id = 0;
 			return FALSE;
