@@ -7,6 +7,7 @@
 #include <SDL.h>
 
 #include "override.h"
+#include "private.h"
 #include "debug.h"
 
 #define DEBUG_DOMAIN    "ACCEL"
@@ -81,7 +82,7 @@ static inline void maybe_update(Uint8 axis, Sint16 * value, int new)
 			fake->which = 0;
 			fake->axis = axis;
 			fake->value = scaled;
-			SDL_PushEvent(&fakeevent);
+			SDLPRE_PushEvent(&fakeevent);
 		}
 		*value = scaled;
 	}
@@ -117,7 +118,7 @@ static int accel_update()
 		return 0;
 	}
 
-	/* Note the rotation */
+	/* Mind the rotation */
 	maybe_update(0, &accel.x, y);
 	maybe_update(1, &accel.y, -x);
 	maybe_update(2, &accel.z, z);
