@@ -179,7 +179,7 @@ static void loc_error_cb(LocationGPSDControl *control, LocationGPSDControlError
 	event.type = SDL_USEREVENT;
 	event.user.code = PDL_GPS_FAILURE;
 	event.user.data1 = &last_loc_error;
-	SDL_PushEvent(&event);
+	SDLPRE_PushEvent(&event);
 }
 
 static void loc_changed_cb(LocationGPSDevice *device, gpointer user_data)
@@ -218,7 +218,7 @@ static void loc_changed_cb(LocationGPSDevice *device, gpointer user_data)
 	event.type = SDL_USEREVENT;
 	event.user.code = PDL_GPS_UPDATE;
 	event.user.data1 = &last_loc;
-	SDL_PushEvent(&event);
+	SDLPRE_PushEvent(&event);
 }
 #endif
 
@@ -282,6 +282,11 @@ PDL_Err PDL_Init(unsigned int flags)
 
 	TRACE("Init: Service name is %s", servicename);
 
+	/* Root check. */
+	if (geteuid() == 0) {
+		WARN("You are root. Don't do this unless you know what you're doing!");
+	}
+
 	/* Prepare libosso. This also sets up the D-BUS connections. */
 	osso_context = osso_initialize(servicename, "0.1", TRUE, NULL);
 	if (!osso_context) {
@@ -547,7 +552,7 @@ PDL_Err PDL_GetOSVersion(PDL_OSVersion *version)
 	version->majorVersion = 1;
 	version->minorVersion = 4;
 	version->revision = 5;
-	version->versionStr = "Preenv 0.1.3";
+	version->versionStr = "Preenv 0.1.4";
 	return PDL_NOERROR;
 }
 
@@ -688,9 +693,8 @@ PDL_Err PDL_SetFirewallPortStatus(int port, PDL_bool open)
 
 PDL_Err PDL_SetOrientation(PDL_Orientation orientation)
 {
-	TRACE("Switch orientation to %hu", orientation);
-	v_orient = orientation;
-	SDLPRE_RefreshScale();
+	TRACE("Switch UI orientation to %u°", orientation * 90);
+	/* TODO */
 	return PDL_NOERROR;
 }
 
@@ -698,7 +702,7 @@ void PDL_NotifyFocus(SDL_bool focus)
 {
 	if (dimming_prevention_enabled) {
 		if (focus) {
-			/* Gaining focus; readd timer. */
+			/* Gaining focus; add timer. */
 			if (!dimming_timer_id) {
 				dimming_timer_id = g_timeout_add_seconds(SCREEN_TIMEOUT_TIME,
 					screen_timeout_cb, NULL);
